seq/fold_right.hpp

The seq/fold_right.hpp header defines macros for folding (or accumulating) a seq right-to-left.

#### Usage

#include <boost/preprocessor/seq/fold_right.hpp>

#### Contents

- BOOST_PP_SEQ_FOLD_RIGHT
- BOOST_PP_SEQ_FOLD_RIGHT_s

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)